==> rubicore-core.2.12.0-rc.0.zip: rubicore-core/controllers/course/course-controller.php <==
<?php

namespace Rubicore\Core;

use \WP_REST_Request, \WP_User;

final class Course_Controller
{

	function __construct()
	{
		$this->routes();
	}

	private function routes(): void
	{
		$api = new Api_Helper('rubicore/core/v1');

		$api->add_route('course', 'GET', function (WP_REST_Request $req, WP_User $user) : array {
				User_Helper::allowed_to('course_list', $user);

				$post_service = new Post_Service();
				$params = $req->get_params();

				return $post_service->get($params, $user, ['course']);
			},
			array(
				'args' => Post_Service::get_args()
			)
		);

		$api->add_route('my-course', 'GET', function (WP_REST_Request $req, WP_User $user) : array {
				$params = $req->get_params();

				return Course_Service::get_my($user->ID, $params);
			},
			array(
				'args' => Post_Service::get_args()
			)
		);

		$api->add_route('course/(?P<slug>[^/]+?)', 'GET', function (WP_REST_Request $req, WP_User $user): Post_Model {
			$post = Post_Service::get_by_slug($req->get_param('slug'), 'course');

			if (!$post) {
				Response_Helper::not_found('No post found with provided id.');
			}

			User_Helper::allowed_to('post_get', $user, [$post->author->id, ...$post->editorIds]);

			return $post;
		}, array(
			'args' => array(
				'slug' => array(
					'type' => [Api_Helper::TYPE_INT, Api_Helper::TYPE_STRING]
				)
			)
		));


		$api->add_route('course', 'POST', function (WP_REST_Request $req, WP_User $user) : int {
				User_Helper::allowed_to('course_add', $user);

				return Post_Service::post($req, $user);
			},
			array(
				'args' => array_merge(
					Post_Service::post_args(),
					Course_Service::post_args()
				)
			)
		);

		$api->add_route('course/(?P<course_id>[^/]+?)', 'PUT', function (WP_REST_Request $req, WP_User $user): void {
			$body = Request_Helper::get_body($req);
			$body->authorId = !is_null($body->authorId) ? $body->authorId : $user->ID;

			$post_repo = new Post_Repository();
			$post_id = $req->get_param('course_id');
			$post = $post_repo->get_by_slug($post_id, null);

			if (!$post) {
				Response_Helper::not_found('No course found with provided id.');
			}

			User_Helper::allowed_to('course_edit', $user, [$post->post_author, ...$post->editor_ids]);

			Post_Service::update($post_id, $req, $user);
			Course_Service::update_reserves($post_id);
		},
			[
				'args' => array_merge(
					Post_Service::post_args(),
					Course_Service::post_args()
				)
			]
		);


		$api->add_route('course/(?P<post_id>[^/]+?)/attendee/(?P<user_id>[^/]+?)', 'POST', function (WP_REST_Request $req, WP_User $user): void {
			$post_id = $req->get_param('post_id');
			$user_id = $req->get_param('user_id');
			$body = Request_Helper::get_body($req);

			Course_Service::add_attendee($post_id, $user_id, $body);
		}, [
			'args' => Course_Service::attendee_post_args()
		]);

		$api->add_route('course/(?P<post_id>[^/]+?)/attendee-external', 'POST', function (WP_REST_Request $req, WP_User $user): void {
			$post_id = $req->get_param('post_id');
			$body = Request_Helper::get_body($req);

			Course_Service::add_attendee_external($post_id, $body->name, $body->email, $body);
		}, [
			'args' => [
				'post_id' => [
					'in' => Api_Helper::IN_PATH,
					'type' => Api_Helper::TYPE_INT,
					'required' => true,
					'minimum' => 1
				],

				'information' => [
					'in' => Api_Helper::IN_BODY,
					'type' => Api_Helper::TYPE_STRING,
					'required' => false
				],
				'name' => ['type' => Api_Helper::TYPE_STRING, 'required' => true],
				'email' => ['type' => Api_Helper::TYPE_STRING, 'required' => true]
			]
		]);

		$api->add_route('course/(?P<post_id>[^/]+?)/attendee/(?P<user_id>[^/]+?)', 'PUT', function (WP_REST_Request $req, WP_User $user) : void {
			$post_id = $req->get_param('post_id');
			$user_id = $req->get_param('user_id');
			$body = Request_Helper::get_body($req);

			Course_Service::update_attendee($post_id, $user_id, $body, $user);
		}, [
			'args' => Course_Service::attendee_put_args()
		]);

		$api->add_route('course/(?P<post_id>[^/]+?)/attendee/(?P<user_id>[^/]+?)', 'DELETE', function (WP_REST_Request $req, WP_User $user): void {
			$post_id = $req->get_param('post_id');
			$user_id = $req->get_param('user_id');

			Course_Service::remove_attendee($post_id, $user_id, $user);
		}, [
			'args' => [
				'post_id' => [
					'in' => Api_Helper::IN_PATH,
					'type' => Api_Helper::TYPE_INT,
					'required' => true,
					'minimum' => 1
				],

				'user_id' => [
					'in' => Api_Helper::IN_PATH,
					'type' => Api_Helper::TYPE_INT,
					'required' => true,
					'minimum' => 1
				]
			]
		]);

	}
}

==> rubicore-core.2.13.1-rc.0.zip: rubicore-core/controllers/course/course-controller.php <==
<?php

namespace Rubicore\Core;

use \WP_REST_Request, \WP_User;

final class Course_Controller
{

	function __construct()
	{
		$this->routes();
	}

	private function routes(): void
	{
		$api = new Api_Helper('rubicore/core/v1');

		$api->add_route('course', 'GET', function (WP_REST_Request $req, WP_User $user) : array {
				User_Helper::allowed_to('course_list', $user);

				$post_service = new Post_Service();
				$params = $req->get_params();
				$params['type'] = 'course';

				return $post_service->get($params, $user);
			},
			array(
				'args' => Post_Service::get_args()
			)
		);

		$api->add_route('my-course', 'GET', function (WP_REST_Request $req, WP_User $user) : array {
				$params = $req->get_params();

				return Course_Service::get_my($user->ID, $params);
			},
			array(
				'args' => Post_Service::get_args()
			)
		);

		$api->add_route('course/(?P<slug>[^/]+?)', 'GET', function (WP_REST_Request $req, WP_User $user): Post_Model {
			$post = Post_Service::get_by_slug($req->get_param('slug'), 'course');

			if (!$post) {
				Response_Helper::not_found('No post found with provided id.');
			}

			User_Helper::allowed_to('post_get', $user, [$post->author->id, ...$post->editorIds]);

			return $post;
		}, array(
			'args' => array(
				'slug' => array(
					'type' => [Api_Helper::TYPE_INT, Api_Helper::TYPE_STRING]
				)
			)
		));


		$api->add_route('course', 'POST', function (WP_REST_Request $req, WP_User $user) : int {
				User_Helper::allowed_to('course_add', $user);

				return Post_Service::post($req, $user);
			},
			array(
				'args' => array_merge(
					Post_Service::post_args(),
					Course_Service::post_args()
				)
			)
		);

		$api->add_route('course/(?P<course_id>[^/]+?)', 'PUT', function (WP_REST_Request $req, WP_User $user): void {
			$body = Request_Helper::get_body($req);
			$body->authorId = !is_null($body->authorId) ? $body->authorId : $user->ID;

			$post_repo = new Post_Repository();
			$post_id = $req->get_param('course_id');
			$post = $post_repo->get_by_slug($post_id, null);

			if (!$post) {
				Response_Helper::not_found('No course found with provided id.');
			}

			User_Helper::allowed_to('course_edit', $user, [$post->post_author, ...$post->editor_ids]);

			Post_Service::update($post_id, $req, $user);
			Course_Service::update_reserves($post_id);
		},
			[
				'args' => array_merge(
					Post_Service::post_args(),
					Course_Service::post_args()
				)
			]
		);


		$api->add_route('course/(?P<post_id>[^/]+?)/attendee/(?P<user_id>[^/]+?)', 'POST', function (WP_REST_Request $req, WP_User $user): void {
			$post_id = $req->get_param('post_id');
			$user_id = $req->get_param('user_id');
			$body = Request_Helper::get_body($req);

			Course_Service::add_attendee($post_id, $user_id, $body);
		}, [
			'args' => Course_Service::attendee_post_args()
		]);

		$api->add_route('course/(?P<post_id>[^/]+?)/attendee-external', 'POST', function (WP_REST_Request $req, WP_User $user): void {
			$post_id = $req->get_param('post_id');
			$body = Request_Helper::get_body($req);

			Course_Service::add_attendee_external($post_id, $body->name, $body->email, $body);
		}, [
			'args' => [
				'post_id' => [
					'in' => Api_Helper::IN_PATH,
					'type' => Api_Helper::TYPE_INT,
					'required' => true,
					'minimum' => 1
				],

				'information' => [
					'in' => Api_Helper::IN_BODY,
					'type' => Api_Helper::TYPE_STRING,
					'required' => false
				],
				'name' => ['type' => Api_Helper::TYPE_STRING, 'required' => true],
				'email' => ['type' => Api_Helper::TYPE_STRING, 'required' => true]
			]
		]);

		$api->add_route('course/(?P<post_id>[^/]+?)/attendee/(?P<user_id>[^/]+?)', 'PUT', function (WP_REST_Request $req, WP_User $user) : void {
			$post_id = $req->get_param('post_id');
			$user_id = $req->get_param('user_id');
			$body = Request_Helper::get_body($req);

			Course_Service::update_attendee($post_id, $user_id, $body, $user);
		}, [
			'args' => Course_Service::attendee_put_args()
		]);

		$api->add_route('course/(?P<post_id>[^/]+?)/attendee/(?P<user_id>[^/]+?)', 'DELETE', function (WP_REST_Request $req, WP_User $user): void {
			$post_id = $req->get_param('post_id');
			$user_id = $req->get_param('user_id');

			Course_Service::remove_attendee($post_id, $user_id, $user);
		}, [
			'args' => [
				'post_id' => [
					'in' => Api_Helper::IN_PATH,
					'type' => Api_Helper::TYPE_INT,
					'required' => true,
					'minimum' => 1
				],

				'user_id' => [
					'in' => Api_Helper::IN_PATH,
					'type' => Api_Helper::TYPE_INT,
					'required' => true,
					'minimum' => 1
				]
			]
		]);

	}
}
